@@ -24,22 +24,11 @@
 #include <kscreen/output.h>
 #include <kscreen/config.h>
 
-#include <QGraphicsScene>
-
 #include <QTimer>
 #include <sys/socket.h>
 
-//static void NullDeleter(KScreen::Output */*output*/) { }
-
-QMLScreen::QMLScreen(QQuickItem *parent):
-    QQuickItem(parent),
-    m_config(nullptr),
-    m_connectedOutputsCount(0),
-    m_enabledOutputsCount(0),
-    m_leftmost(nullptr),
-    m_topmost(nullptr),
-    m_rightmost(nullptr),
-    m_bottommost(nullptr)
+QMLScreen::QMLScreen(QQuickItem *parent)
+    : QQuickItem(parent)
 {
     connect(this, &QMLScreen::widthChanged, this, &QMLScreen::viewSizeChanged);
     connect(this, &QMLScreen::heightChanged, this, &QMLScreen::viewSizeChanged);
@@ -47,6 +36,8 @@ QMLScreen::QMLScreen(QQuickItem *parent):
 
 QMLScreen::~QMLScreen()
 {
+    qDeleteAll(m_outputMap);
+    m_outputMap.clear();
 }
 
 KScreen::ConfigPtr QMLScreen::config() const
@@ -91,9 +82,7 @@ void QMLScreen::setConfig(const KScreen::ConfigPtr &config)
 
 void QMLScreen::addOutput(const KScreen::OutputPtr &output)
 {
-    //QQuickItem *container = findChild<QQuickItem*>(QLatin1String("outputContainer"));
-
-    QMLOutputComponent comp(m_engine, this);
+    QMLOutputComponent comp(qmlEngine(this), this);
     QMLOutput *qmloutput = comp.createForOutput(output);
     if (!qmloutput) {
         qWarning() << "Failed to create QMLOutput";
@@ -130,8 +119,8 @@ void QMLScreen::removeOutput(int outputId)
     for (const KScreen::OutputPtr &output : m_outputMap.keys()) {
         if (output->id() == outputId) {
             QMLOutput *qmlOutput = m_outputMap.take(output);
-            qmlOutput->setParentItem(Q_NULLPTR);
-            qmlOutput->setParent(Q_NULLPTR);
+            qmlOutput->setParentItem(nullptr);
+            qmlOutput->setParent(nullptr);
             qmlOutput->deleteLater();
             return;
         }
@@ -359,8 +348,3 @@ void QMLScreen::updateOutputsPlacement()
         qmlOutput->blockSignals(false);
     }
 }
-
-void QMLScreen::setEngine(QQmlEngine* engine)
-{
-    m_engine = engine;
-}
