@@ -52,13 +52,9 @@ class QMLScreen : public QQuickItem
                READ outputScale
                NOTIFY outputScaleChanged)
 
-    Q_PROPERTY(QQmlEngine* engine
-               MEMBER m_engine)
-
   public:
     explicit QMLScreen(QQuickItem *parent = nullptr);
-    virtual ~QMLScreen();
-
+    ~QMLScreen() override;
 
     int connectedOutputsCount() const;
     int enabledOutputsCount() const;
@@ -74,7 +70,6 @@ class QMLScreen : public QQuickItem
     void setConfig(const KScreen::ConfigPtr &config);
 
     void updateOutputsPlacement();
-    void setEngine(QQmlEngine* engine);
 
     void setActiveOutput(QMLOutput *output);
 
@@ -105,15 +100,12 @@ class QMLScreen : public QQuickItem
   private:
     void qmlOutputMoved(QMLOutput *qmlOutput);
     void updateCornerOutputs();
-    void setOutputScale(float scale);
 
     KScreen::ConfigPtr m_config;
     QHash<KScreen::OutputPtr,QMLOutput*> m_outputMap;
-    int m_connectedOutputsCount;
-    int m_enabledOutputsCount;
-    float m_outputScale = 1.0 / 8.0;
+    int m_connectedOutputsCount = 0;
+    int m_enabledOutputsCount = 0;
 
-    QQmlEngine* m_engine = nullptr;
     QMLOutput *m_leftmost = nullptr;
     QMLOutput *m_topmost = nullptr;
     QMLOutput *m_rightmost = nullptr;
