@@ -50,7 +50,6 @@ Q_DECLARE_METATYPE(KScreen::ScreenPtr)
 
 KCMKScreen::KCMKScreen(QWidget* parent, const QVariantList& args)
     : KCModule(parent, args)
-    , mKScreenWidget(nullptr)
 {
     Log::instance();
 
@@ -88,8 +87,6 @@ void KCMKScreen::configReady(ConfigOperation* op)
         mMainLayout->addWidget(mKScreenWidget);
         QObject::connect(mKScreenWidget, &Widget::changed,
                 this, &KCMKScreen::changed);
-    } else {
-        mMainLayout->addWidget(mKScreenWidget);
     }
 
     mKScreenWidget->setConfig(qobject_cast<GetConfigOperation*>(op)->config());
